@@ -24,10 +24,7 @@
 
 /*****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -35,22 +32,22 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdarg.h>
-#include <asm/byteorder.h>
-#define le16_to_cpu	__le16_to_cpu
+#include <byteswap.h>
 #include <usb.h>
 
-/* NOTE:  that should be <libusb.h> and it should include
- * <linux/usb_ch9.h> ... without it, we keep accumulating
- * potentially broken variants of standard types ...
- */
-
 #include "names.h"
 #include "devtree.h"
 #include "usbmisc.h"
 
-#define _GNU_SOURCE
 #include <getopt.h>
 
+#if (__BYTE_ORDER == __LITTLE_ENDIAN)
+  #define le16_to_cpu(x) (x)
+#elif (__BYTE_ORDER == __BIG_ENDIAN)
+  #define le16_to_cpu(x) bswap_16(x)
+#else
+  #error missing BYTE_ORDER
+#endif
 
 /* from USB 2.0 spec and updates */
 #define USB_DT_DEVICE_QUALIFIER		0x06
@@ -139,6 +136,11 @@ static int get_string(struct usb_dev_handle *dev, char* buf, size_t size, u_int8
 {
 	int ret;
 
+	if (!dev) {
+		buf[0] = 0;
+		return 0;
+	}
+
 	if (id) {
 		ret = usb_get_string_simple(dev, id, buf, size);
 		if (ret <= 0) {
@@ -1522,7 +1524,7 @@ static void dump_videostreaming_interface(unsigned char *buf)
 		n = buf[12];
 		if (buf[0] < 13+p*n)
 			printf("      Warning: Descriptor too short\n");
-		printf("        bNumFormats                    %5u\n"
+		printf("        bNumFormats                     %5u\n"
 		       "        wTotalLength                    %5u\n"
 		       "        bEndPointAddress                %5u\n"
 		       "        bmInfo                          %5u\n"
@@ -2069,6 +2071,12 @@ static void dump_hid_device(struct usb_dev_handle *dev, struct usb_interface_des
 	if (!do_report_desc)
 		return;
 
+	if (!dev) {
+		printf( "         Report Descriptors: \n"
+			"           ** UNAVAILABLE **\n");
+		return;
+	}
+
 	for (i = 0; i < buf[5]; i++) {
 		/* we are just interested in report descriptors*/
 		if (buf[6+3*i] != USB_DT_REPORT)
@@ -2637,6 +2645,8 @@ dump_device_status(struct usb_dev_handle *fd, int otg, int wireless)
 static int do_wireless(struct usb_dev_handle *fd)
 {
 	/* FIXME fetch and dump BOS etc */
+	if (fd)
+		return 0;
 	return 0;
 }
 
@@ -2648,28 +2658,31 @@ static void dumpdev(struct usb_device *dev)
 
 	otg = wireless = 0;
 	udev = usb_open(dev);
-	if (udev) {
-		dump_device(udev, &dev->descriptor);
-		if (dev->descriptor.bcdUSB >= 0x0250)
-			wireless = do_wireless(udev);
-		if (dev->config) {
-			otg = do_otg(&dev->config[0]) || otg;
-			for (i = 0; i < dev->descriptor.bNumConfigurations;
-					i++) {
-				dump_config(udev, &dev->config[i]);
-			}
+	if (!udev)
+		fprintf(stderr, "Couldn't open device, some information "
+			"will be missing\n");
+
+	dump_device(udev, &dev->descriptor);
+	if (dev->descriptor.bcdUSB >= 0x0250)
+		wireless = do_wireless(udev);
+	if (dev->config) {
+		otg = do_otg(&dev->config[0]) || otg;
+		for (i = 0; i < dev->descriptor.bNumConfigurations;
+				i++) {
+			dump_config(udev, &dev->config[i]);
 		}
-		if (dev->descriptor.bDeviceClass == USB_CLASS_HUB)
-			do_hub(udev, dev->descriptor.bDeviceProtocol);
-		if (dev->descriptor.bcdUSB >= 0x0200) {
-			do_dualspeed(udev);
-			do_debug(udev);
-		}
-		dump_device_status(udev, otg, wireless);
-		usb_close(udev);
 	}
-	else
-		fprintf(stderr, "Couldn't open device\n");
+	if (!udev)
+		return;
+
+	if (dev->descriptor.bDeviceClass == USB_CLASS_HUB)
+		do_hub(udev, dev->descriptor.bDeviceProtocol);
+	if (dev->descriptor.bcdUSB >= 0x0200) {
+		do_dualspeed(udev);
+		do_debug(udev);
+	}
+	dump_device_status(udev, otg, wireless);
+	usb_close(udev);
 }
 
 /* ---------------------------------------------------------------------- */
@@ -2867,29 +2880,16 @@ int main(int argc, char *argv[])
 	}
 
 	/* by default, print names as well as numbers */
+	err = names_init(DATADIR "/usb.ids");
 #ifdef HAVE_LIBZ
-	err = names_init("./usb.ids");
 	if (err != 0)
-		err = names_init("./usb.ids.gz");
-	if (err != 0)
-		err = names_init(USBIDS_DIR "/usb.ids");
-	if (err != 0)
-		err = names_init(USBIDS_DIR "/usb.ids.gz");
+		err = names_init(DATADIR "/usb.ids.gz");
+#endif
 	if (err != 0)
 		fprintf(stderr, "%s: cannot open \"%s\", %s\n",
 				argv[0],
-				USBIDS_DIR"/usb.ids",
+				DATADIR "/usb.ids",
 				strerror(err));
-#else
-	if ((err = names_init("./usb.ids")) != 0) {
-		if ((err = names_init(USBIDS_DIR"/usb.ids")) != 0) {
-			fprintf(stderr, "%s: cannot open \"%s\", %s\n",
-					argv[0],
-					USBIDS_DIR"/usb.ids",
-					strerror(err));
-		}
-	}
-#endif
 	status = 0;
 
 	usb_init();
@@ -2897,7 +2897,6 @@ int main(int argc, char *argv[])
 	usb_find_busses();
 	usb_find_devices();
 
-
 	if (treemode) {
 		/* treemode requires at least verblevel 1 */
  		verblevel += 1 - VERBLEVEL_DEFAULT;
